==> PDAL-2.8.4-src.tar.bz2: PDAL-2.8.4-src/plugins/nitf/io/MetadataReader.hpp <==
/******************************************************************************
* Copyright (c) 2014, Michael P. Gerlek (mpg@flaxen.com)
*
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following
* conditions are met:
*
*     * Redistributions of source code must retain the above copyright
*       notice, this list of conditions and the following disclaimer.
*     * Redistributions in binary form must reproduce the above copyright
*       notice, this list of conditions and the following disclaimer in
*       the documentation and/or other materials provided
*       with the distribution.
*     * Neither the name of Hobu, Inc. or Flaxen Consulting LLC nor the
*       names of its contributors may be used to endorse or promote
*       products derived from this software without specific prior
*       written permission.
*
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
* "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
* LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
* FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
* COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
* INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
* BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
* OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
* AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
* OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
* OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY
* OF SUCH DAMAGE.
****************************************************************************/

#pragma once

#include <pdal/pdal_internal.hpp>

#include <vector>

#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wpragmas"
#pragma GCC diagnostic ignored "-Wredundant-decls"
#pragma GCC diagnostic ignored "-Wextra"
#pragma GCC diagnostic ignored "-Wcast-qual"
#pragma GCC diagnostic ignored "-Wunused-private-field"

#include <nitro/c++/import/nitf.hpp>

#pragma GCC diagnostic pop

namespace pdal
{
    class MetadataNode;
}

namespace pdal
{

//
// helper class for processing all the metadata fields
//
class PDAL_DLL MetadataReader
{
public:
    struct error : public std::runtime_error
    {
        error(const std::string& err) : std::runtime_error(err)
        {}
    };

    MetadataReader(::nitf::Record&, MetadataNode&, bool showEmptyFields=true);

    void read();

private:
    ::nitf::Record m_record;
    MetadataNode& m_node;
    const bool m_showEmptyFields;

    void writeField(const std::string& parentkey,
                    const std::string& key,
                    ::nitf::Field field);
    void writeInt(const std::string& parentkey,
                  const std::string& key,
                  int thevalue);
    void writeString(const std::string& parentkey,
                     const std::string& key,
                     const std::string& thevalue);

    void doFileHeader(const std::string& parentkey,
                      ::nitf::FileHeader&);

    void doSecurity(const std::string& parentkey,
                    const std::string& prefix,
                    ::nitf::FileSecurity&);

    void doBands(const std::string& key,
                 ::nitf::ImageSubheader&);
    void doBand(const std::string& key,
                 ::nitf::BandInfo&);

    void doImageSubheader(const std::string& key,
                          ::nitf::ImageSubheader&);

    void doDESubheader(const std::string& key,
                      ::nitf::DESubheader&);

    void doExtensions(const std::string& key,
                      ::nitf::Extensions&);

    void doComments(const std::string& key,
                    ::nitf::List&);

    void doTRE(const std::string& key,
               ::nitf::TRE&);

    MetadataReader(const MetadataReader&); // nope
    MetadataReader& operator=(const MetadataReader&); // nope
};


} // namespaces

==> PDAL-2.10.0-src.tar.bz2: PDAL-2.10.0-src/plugins/nitf/io/MetadataReader.hpp <==
/******************************************************************************
* Copyright (c) 2014, Michael P. Gerlek (mpg@flaxen.com)
*
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following
* conditions are met:
*
*     * Redistributions of source code must retain the above copyright
*       notice, this list of conditions and the following disclaimer.
*     * Redistributions in binary form must reproduce the above copyright
*       notice, this list of conditions and the following disclaimer in
*       the documentation and/or other materials provided
*       with the distribution.
*     * Neither the name of Hobu, Inc. or Flaxen Consulting LLC nor the
*       names of its contributors may be used to endorse or promote
*       products derived from this software without specific prior
*       written permission.
*
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
* "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
* LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
* FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
* COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
* INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
* BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
* OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
* AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
* OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
* OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY
* OF SUCH DAMAGE.
****************************************************************************/

#pragma once

#include <pdal/pdal_internal.hpp>

#include <vector>

#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wpragmas"
#pragma GCC diagnostic ignored "-Wredundant-decls"
#pragma GCC diagnostic ignored "-Wextra"
#pragma GCC diagnostic ignored "-Wcast-qual"
#pragma GCC diagnostic ignored "-Wunused-private-field"

#include <nitro/c++/import/nitf.hpp>

#pragma GCC diagnostic pop

namespace pdal
{
    class MetadataNode;
}

namespace pdal
{

//
// helper class for processing all the metadata fields
//
class PDAL_EXPORT MetadataReader
{
public:
    struct error : public std::runtime_error
    {
        error(const std::string& err) : std::runtime_error(err)
        {}
    };

    MetadataReader(::nitf::Record&, MetadataNode&, bool showEmptyFields=true);

    void read();

private:
    ::nitf::Record m_record;
    MetadataNode& m_node;
    const bool m_showEmptyFields;

    void writeField(const std::string& parentkey,
                    const std::string& key,
                    ::nitf::Field field);
    void writeInt(const std::string& parentkey,
                  const std::string& key,
                  int thevalue);
    void writeString(const std::string& parentkey,
                     const std::string& key,
                     const std::string& thevalue);

    void doFileHeader(const std::string& parentkey,
                      ::nitf::FileHeader&);

    void doSecurity(const std::string& parentkey,
                    const std::string& prefix,
                    ::nitf::FileSecurity&);

    void doBands(const std::string& key,
                 ::nitf::ImageSubheader&);
    void doBand(const std::string& key,
                 ::nitf::BandInfo&);

    void doImageSubheader(const std::string& key,
                          ::nitf::ImageSubheader&);

    void doDESubheader(const std::string& key,
                      ::nitf::DESubheader&);

    void doExtensions(const std::string& key,
                      ::nitf::Extensions&);

    void doComments(const std::string& key,
                    ::nitf::List&);

    void doTRE(const std::string& key,
               ::nitf::TRE&);

    MetadataReader(const MetadataReader&); // nope
    MetadataReader& operator=(const MetadataReader&); // nope
};


} // namespaces
